@@ -1,18 +1,6 @@
-"""
-    weasyprint.tests.test_draw.svg.test_opacity
-    -------------------------------------------
-
-    Test how opacity is handled for SVG.
-
-"""
-
-import pytest
+"""Test how opacity is handled for SVG."""
 
 from ...testing_utils import assert_no_logs
-from .. import assert_same_rendering
-
-# TODO: xfail tests fail because of GhostScript and are supposed to work with
-# real PDF files.
 
 opacity_source = '''
   <style>
@@ -23,75 +11,72 @@ opacity_source = '''
 
 
 @assert_no_logs
-def test_opacity():
-    assert_same_rendering(9, 9, (
-        ('opacity_reference', opacity_source % '''
+def test_opacity(assert_same_renderings):
+    assert_same_renderings(
+        '''
             <rect x="2" y="2" width="5" height="5" stroke-width="2"
                   stroke="rgb(127, 255, 127)" fill="rgb(127, 127, 255)" />
-        '''),
-        ('opacity', opacity_source % '''
+        ''',
+        '''
             <rect x="2" y="2" width="5" height="5" stroke-width="2"
                   stroke="lime" fill="blue" opacity="0.5" />
-        '''),
-    ))
+        ''',
+    )
 
 
 @assert_no_logs
-def test_fill_opacity():
-    assert_same_rendering(9, 9, (
-        ('fill_opacity_reference', opacity_source % '''
+def test_fill_opacity(assert_same_renderings):
+    assert_same_renderings(
+        '''
             <rect x="2" y="2" width="5" height="5"
                   fill="blue" opacity="0.5" />
             <rect x="2" y="2" width="5" height="5" stroke-width="2"
                   stroke="lime" fill="transparent" />
-        '''),
-        ('fill_opacity', opacity_source % '''
+        ''',
+        '''
             <rect x="2" y="2" width="5" height="5" stroke-width="2"
                   stroke="lime" fill="blue" fill-opacity="0.5" />
-        '''),
-    ))
+        ''',
+    )
 
 
-@pytest.mark.xfail
 @assert_no_logs
-def test_stroke_opacity():
-    assert_same_rendering(9, 9, (
-        ('stroke_opacity_reference', opacity_source % '''
+def test_stroke_opacity(assert_same_renderings):
+    assert_same_renderings(
+        '''
             <rect x="2" y="2" width="5" height="5"
                   fill="blue" />
             <rect x="2" y="2" width="5" height="5" stroke-width="2"
                   stroke="lime" fill="transparent" opacity="0.5" />
-        '''),
-        ('stroke_opacity', opacity_source % '''
+        ''',
+        '''
             <rect x="2" y="2" width="5" height="5" stroke-width="2"
                   stroke="lime" fill="blue" stroke-opacity="0.5" />
-        '''),
-    ))
+        ''',
+    )
 
 
-@pytest.mark.xfail
 @assert_no_logs
-def test_stroke_fill_opacity():
-    assert_same_rendering(9, 9, (
-        ('stroke_fill_opacity_reference', opacity_source % '''
+def test_stroke_fill_opacity(assert_same_renderings):
+    assert_same_renderings(
+        '''
             <rect x="2" y="2" width="5" height="5"
                   fill="blue" opacity="0.5" />
             <rect x="2" y="2" width="5" height="5" stroke-width="2"
                   stroke="lime" fill="transparent" opacity="0.5" />
-        '''),
-        ('stroke_fill_opacity', opacity_source % '''
+        ''',
+        '''
             <rect x="2" y="2" width="5" height="5" stroke-width="2"
                   stroke="lime" fill="blue"
                   stroke-opacity="0.5" fill-opacity="0.5" />
-        '''),
-    ))
+        ''',
+    )
 
 
-@pytest.mark.xfail
 @assert_no_logs
-def test_pattern_gradient_stroke_fill_opacity():
-    assert_same_rendering(9, 9, (
-        ('pattern_gradient_stroke_fill_opacity_reference', opacity_source % '''
+def test_pattern_gradient_stroke_fill_opacity(assert_same_renderings):
+    assert_same_renderings(
+        '''
             <defs>
               <linearGradient id="grad" x1="0" y1="0" x2="0" y2="1"
                               gradientUnits="objectBoundingBox">
@@ -111,8 +96,8 @@ def test_pattern_gradient_stroke_fill_opacity():
                   fill="url(#pat)" opacity="0.5" />
             <rect x="2" y="2" width="5" height="5" stroke-width="2"
                   stroke="url(#grad)" fill="transparent" opacity="0.5" />
-        '''),
-        ('pattern_gradient_stroke_fill_opacity', opacity_source % '''
+        ''',
+        '''
             <defs>
               <linearGradient id="grad" x1="0" y1="0" x2="0" y2="1"
                               gradientUnits="objectBoundingBox">
@@ -131,5 +116,5 @@ def test_pattern_gradient_stroke_fill_opacity():
             <rect x="2" y="2" width="5" height="5" stroke-width="2"
                   stroke="url(#grad)" fill="url(#pat)"
                   stroke-opacity="0.5" fill-opacity="0.5" />
-        '''),
-    ))
+        ''',
+    )
