@@ -1,18 +1,10 @@
-"""
-    weasyprint.tests.test_draw.test_text
-    ------------------------------------
-
-    Test how text is drawn.
-
-"""
+"""Test how text is drawn."""
 
 import pytest
 
-from . import assert_pixels
 
-
-def test_text_overflow_clip():
-    assert_pixels('text_overflow', 9, 7, '''
+def test_text_overflow_clip(assert_pixels):
+    assert_pixels('''
         _________
         _RRRRRRR_
         _RRRRRRR_
@@ -25,7 +17,6 @@ def test_text_overflow_clip():
         @font-face {src: url(weasyprint.otf); font-family: weasyprint}
         @page {
           size: 9px 7px;
-          background: white;
         }
         body {
           color: red;
@@ -43,8 +34,8 @@ def test_text_overflow_clip():
       <div style="white-space: nowrap">a bcde</div>''')
 
 
-def test_text_overflow_ellipsis():
-    assert_pixels('text_overflow', 9, 16, '''
+def test_text_overflow_ellipsis(assert_pixels):
+    assert_pixels('''
         _________
         _RRRRRR__
         _RRRRRR__
@@ -65,7 +56,6 @@ def test_text_overflow_ellipsis():
       <style>
         @font-face {src: url(weasyprint.otf); font-family: weasyprint}
         @page {
-          background: white;
           size: 9px 16px;
         }
         body {
@@ -92,10 +82,10 @@ def test_text_overflow_ellipsis():
 ''')
 
 
-def test_text_align_rtl_trailing_whitespace():
+def test_text_align_rtl_trailing_whitespace(assert_pixels):
     # Test text alignment for rtl text with trailing space.
     # Test regression: https://github.com/Kozea/WeasyPrint/issues/1111
-    assert_pixels('text_overflow', 9, 9, '''
+    assert_pixels('''
         _________
         _rrrrBBB_
         _________
@@ -108,7 +98,7 @@ def test_text_align_rtl_trailing_whitespace():
     ''', '''
       <style>
         @font-face {src: url(weasyprint.otf); font-family: weasyprint}
-        @page { background: white; size: 9px }
+        @page { size: 9px }
         body { font-family: weasyprint; color: blue; font-size: 1px }
         p { background: red; line-height: 1; width: 7em; margin: 1em }
       </style>
@@ -120,8 +110,8 @@ def test_text_align_rtl_trailing_whitespace():
     ''')
 
 
-def test_max_lines_ellipsis():
-    assert_pixels('max_lines_ellipsis', 10, 10, '''
+def test_max_lines_ellipsis(assert_pixels):
+    assert_pixels('''
         BBBBBBBB__
         BBBBBBBB__
         BBBBBBBBBB
@@ -151,8 +141,8 @@ def test_max_lines_ellipsis():
 
 
 @pytest.mark.xfail
-def test_max_lines_nested():
-    assert_pixels('max_lines_nested', 10, 12, '''
+def test_max_lines_nested(assert_pixels):
+    assert_pixels('''
         BBBBBBBBBB
         BBBBBBBBBB
         BBBBBBBBBB
@@ -198,8 +188,8 @@ def test_max_lines_nested():
     ''')
 
 
-def test_line_clamp():
-    assert_pixels('line_clamp', 10, 10, '''
+def test_line_clamp(assert_pixels):
+    assert_pixels('''
         BBBB__BB__
         BBBB__BB__
         BBBB__BB__
@@ -235,8 +225,8 @@ def test_line_clamp():
     ''')
 
 
-def test_line_clamp_none():
-    assert_pixels('line_clamp_none', 10, 10, '''
+def test_line_clamp_none(assert_pixels):
+    assert_pixels('''
         BBBB__BB__
         BBBB__BB__
         BBBB__BB__
@@ -270,8 +260,8 @@ def test_line_clamp_none():
     ''')
 
 
-def test_line_clamp_number():
-    assert_pixels('line_clamp_number', 10, 10, '''
+def test_line_clamp_number(assert_pixels):
+    assert_pixels('''
         BBBB__BB__
         BBBB__BB__
         BBBB__BB__
@@ -304,9 +294,87 @@ def test_line_clamp_number():
     ''')
 
 
+def test_line_clamp_nested(assert_pixels):
+    assert_pixels('''
+        BBBB__BB__
+        BBBB__BB__
+        BBBB__BB__
+        BBBB__BB__
+        BBBBBBBBBB
+        BBBBBBBBBB
+        __________
+        __________
+        __________
+        __________
+    ''', '''
+      <style>
+        @page {size: 10px 10px;}
+        @font-face {src: url(weasyprint.otf); font-family: weasyprint}
+        div {
+          color: blue;
+          font-family: weasyprint;
+          font-size: 2px;
+          line-clamp: 3 "(…)";
+        }
+      </style>
+
+      <div>
+        aa a
+        <p>
+          bb b
+          cc c
+          dddd
+          eeee
+          ffff
+          gggg
+          hhhh
+        </p>
+      </div>
+    ''')
+
+
+def test_line_clamp_nested_after(assert_pixels):
+    assert_pixels('''
+        BBBB__BB__
+        BBBB__BB__
+        BBBB__BB__
+        BBBB__BB__
+        BBBBBBBBBB
+        BBBBBBBBBB
+        __________
+        __________
+        __________
+        __________
+    ''', '''
+      <style>
+        @page {size: 10px 10px;}
+        @font-face {src: url(weasyprint.otf); font-family: weasyprint}
+        div {
+          color: blue;
+          font-family: weasyprint;
+          font-size: 2px;
+          line-clamp: 3 "(…)";
+        }
+      </style>
+
+      <div>
+        aa a
+        <p>
+          bb b
+        </p>
+        cc c
+        dddd
+        eeee
+        ffff
+        gggg
+        hhhh
+      </div>
+    ''')
+
+
 @pytest.mark.xfail
-def test_ellipsis_nested():
-    assert_pixels('ellipsis_nested', 10, 10, '''
+def test_ellipsis_nested(assert_pixels):
+    assert_pixels('''
         BBBBBB____
         BBBBBB____
         BBBBBB____
@@ -340,8 +408,8 @@ def test_ellipsis_nested():
     ''')
 
 
-def test_text_align_right():
-    assert_pixels('text_align_right', 9, 6, '''
+def test_text_align_right(assert_pixels):
+    assert_pixels('''
         _________
         __RR__RR_
         __RR__RR_
@@ -353,7 +421,6 @@ def test_text_align_right():
         @font-face {src: url(weasyprint.otf); font-family: weasyprint}
         @page {
           size: 9px 6px;
-          background: white;
         }
         body {
           color: red;
@@ -369,8 +436,8 @@ def test_text_align_right():
       <div>a c e</div>''')
 
 
-def test_text_align_justify():
-    assert_pixels('text_align_justify', 9, 6, '''
+def test_text_align_justify(assert_pixels):
+    assert_pixels('''
         _________
         _RR___RR_
         _RR___RR_
@@ -382,7 +449,6 @@ def test_text_align_justify():
         @font-face {src: url(weasyprint.otf); font-family: weasyprint}
         @page {
           size: 9px 6px;
-          background: white;
         }
         body {
           color: red;
@@ -398,8 +464,8 @@ def test_text_align_justify():
       <div>a c e</div>''')
 
 
-def test_text_word_spacing():
-    assert_pixels('text_word_spacing', 19, 4, '''
+def test_text_word_spacing(assert_pixels):
+    assert_pixels('''
         ___________________
         _RR____RR____RR____
         _RR____RR____RR____
@@ -409,7 +475,6 @@ def test_text_word_spacing():
         @font-face {src: url(weasyprint.otf); font-family: weasyprint}
         @page {
           size: 19px 4px;
-          background: white;
         }
         body {
           color: red;
@@ -425,8 +490,8 @@ def test_text_word_spacing():
       <div>a c e</div>''')
 
 
-def test_text_letter_spacing():
-    assert_pixels('text_letter_spacing', 19, 4, '''
+def test_text_letter_spacing(assert_pixels):
+    assert_pixels('''
         ___________________
         _RR____RR____RR____
         _RR____RR____RR____
@@ -436,7 +501,6 @@ def test_text_letter_spacing():
         @font-face {src: url(weasyprint.otf); font-family: weasyprint}
         @page {
           size: 19px 4px;
-          background: white;
         }
         body {
           color: red;
@@ -452,8 +516,8 @@ def test_text_letter_spacing():
       <div>ace</div>''')
 
 
-def test_text_underline():
-    assert_pixels('text_underline', 13, 7, '''
+def test_text_underline(assert_pixels):
+    assert_pixels('''
         _____________
         _zzzzzzzzzzz_
         _zRRRRRRRRRz_
@@ -466,7 +530,6 @@ def test_text_underline():
         @font-face {src: url(weasyprint.otf); font-family: weasyprint}
         @page {
           size: 13px 7px;
-          background: white;
           margin: 2px;
         }
         body {
@@ -479,10 +542,10 @@ def test_text_underline():
       <div>abc</div>''')
 
 
-def test_text_overline():
+def test_text_overline(assert_pixels):
     # Ascent value seems to be a bit random, don’t try to get the exact
     # position of the line
-    assert_pixels('text_overline', 13, 7, '''
+    assert_pixels('''
         _____________
         _zzzzzzzzzzz_
         _zzzzzzzzzzz_
@@ -495,7 +558,6 @@ def test_text_overline():
         @font-face {src: url(weasyprint.otf); font-family: weasyprint}
         @page {
           size: 13px 7px;
-          background: white;
           margin: 2px;
         }
         body {
@@ -508,8 +570,8 @@ def test_text_overline():
       <div>abc</div>''')
 
 
-def test_text_line_through():
-    assert_pixels('text_line_through', 13, 7, '''
+def test_text_line_through(assert_pixels):
+    assert_pixels('''
         _____________
         _zzzzzzzzzzz_
         _zRRRRRRRRRz_
@@ -522,7 +584,6 @@ def test_text_line_through():
         @font-face {src: url(weasyprint.otf); font-family: weasyprint}
         @page {
           size: 13px 7px;
-          background: white;
           margin: 2px;
         }
         body {
@@ -535,9 +596,165 @@ def test_text_line_through():
       <div>abc</div>''')
 
 
-def test_zero_width_character():
+def test_text_multiple_text_decoration(assert_pixels):
+    # Test regression: https://github.com/Kozea/WeasyPrint/issues/1621
+    assert_pixels('''
+        _____________
+        _zzzzzzzzzzz_
+        _zRRRRRRRRRz_
+        _zBBBBBBBBBz_
+        _zBBBBBBBBBz_
+        _zzzzzzzzzzz_
+        _____________
+    ''', '''
+      <style>
+        @font-face {src: url(weasyprint.otf); font-family: weasyprint}
+        @page {
+          size: 13px 7px;
+          margin: 2px;
+        }
+        body {
+          color: red;
+          font-family: weasyprint;
+          font-size: 3px;
+          text-decoration: underline line-through blue;
+        }
+      </style>
+      <div>abc</div>''')
+
+
+def test_text_nested_text_decoration(assert_pixels):
+    # Test regression: https://github.com/Kozea/WeasyPrint/issues/1621
+    assert_pixels('''
+        _____________
+        _zzzzzzzzzzz_
+        _zRRRRRRRRRz_
+        _zRRRBBBRRRz_
+        _zBBBBBBBBBz_
+        _zzzzzzzzzzz_
+        _____________
+    ''', '''
+      <style>
+        @font-face {src: url(weasyprint.otf); font-family: weasyprint}
+        @page {
+          size: 13px 7px;
+          margin: 2px;
+        }
+        body {
+          color: red;
+          font-family: weasyprint;
+          font-size: 3px;
+          text-decoration: underline blue;
+        }
+        span {
+          text-decoration: line-through blue;
+        }
+      </style>
+      <div>a<span>b</span>c</div>''')
+
+
+@pytest.mark.xfail
+def test_text_nested_text_decoration_color(assert_pixels):
+    # See weasyprint.css.text_decoration’s TODO
+    assert_pixels('''
+        _____________
+        _zzzzzzzzzzz_
+        _zRRRRRRRRRz_
+        _zRRRGGGRRRz_
+        _zBBBBBBBBBz_
+        _zzzzzzzzzzz_
+        _____________
+    ''', '''
+      <style>
+        @font-face {src: url(weasyprint.otf); font-family: weasyprint}
+        @page {
+          size: 13px 7px;
+          margin: 2px;
+        }
+        body {
+          color: red;
+          font-family: weasyprint;
+          font-size: 3px;
+          text-decoration: underline blue;
+        }
+        span {
+          text-decoration: line-through lime;
+        }
+      </style>
+      <div>a<span>b</span>c</div>''')
+
+
+@pytest.mark.xfail
+def test_text_nested_block_text_decoration(assert_pixels):
+    # See weasyprint.css.text_decoration’s TODO
+    assert_pixels('''
+        _______
+        _zzzzz_
+        _zRRRz_
+        _zRRRz_
+        _zBBBz_
+        _zRRRz_
+        _zGGGz_
+        _zBBBz_
+        _zRRRz_
+        _zRRRz_
+        _zBBBz_
+        _zzzzz_
+        _______
+    ''', '''
+      <style>
+        @font-face {src: url(weasyprint.otf); font-family: weasyprint}
+        @page {
+          size: 7px 13px;
+          margin: 2px;
+        }
+        body {
+          color: red;
+          font-family: weasyprint;
+          font-size: 3px;
+          text-decoration: underline blue;
+        }
+        article {
+          text-decoration: line-through lime;
+        }
+      </style>
+      <div>a<article>b</article>c</div>''')
+
+
+@pytest.mark.xfail
+def test_text_float_text_decoration(assert_pixels):
+    # See weasyprint.css.text_decoration’s TODO
+    assert_pixels('''
+        _____________
+        _zzzzz_______
+        _zRRRz__RRR__
+        _zRRRz__RRR__
+        _zBBBz__RRR__
+        _zzzzz_______
+        _____________
+    ''', '''
+      <style>
+        @font-face {src: url(weasyprint.otf); font-family: weasyprint}
+        @page {
+          size: 13px 7px;
+          margin: 2px;
+        }
+        div {
+          color: red;
+          font-family: weasyprint;
+          font-size: 3px;
+          text-decoration: underline blue;
+        }
+        span {
+          float: right;
+        }
+      </style>
+      <div>a<span>b</span></div>''')
+
+
+def test_zero_width_character(assert_pixels):
     # Test regression: https://github.com/Kozea/WeasyPrint/issues/1508
-    assert_pixels('zero_width_character', 6, 4, '''
+    assert_pixels('''
         ______
         _RRRR_
         _RRRR_
@@ -547,7 +764,6 @@ def test_zero_width_character():
         @font-face {src: url(weasyprint.otf); font-family: weasyprint}
         @page {
           size: 6px 4px;
-          background: white;
           margin: 1px;
         }
         body {
@@ -560,9 +776,31 @@ def test_zero_width_character():
       <div>a&zwnj;b</div>''')
 
 
-def test_tabulation_character():
+def test_font_size_very_small(assert_pixels):
+    assert_pixels('''
+        __________
+        __________
+        __________
+        __________
+    ''', '''
+      <style>
+        @font-face {src: url(weasyprint.otf); font-family: weasyprint}
+        @page {
+          size: 10px 4px;
+          margin: 1px;
+        }
+        body {
+          font-family: weasyprint;
+          font-size: 0.00000001px;
+        }
+      </style>
+      test font size zero
+    ''')
+
+
+def test_tabulation_character(assert_pixels):
     # Test regression: https://github.com/Kozea/WeasyPrint/issues/1515
-    assert_pixels('zero_width_character', 10, 4, '''
+    assert_pixels('''
         __________
         _RR____RR_
         _RR____RR_
@@ -572,7 +810,6 @@ def test_tabulation_character():
         @font-face {src: url(weasyprint.otf); font-family: weasyprint}
         @page {
           size: 10px 4px;
-          background: white;
           margin: 1px;
         }
         body {
@@ -584,3 +821,31 @@ def test_tabulation_character():
         }
       </style>
       <pre>a&Tab;b</pre>''')
+
+
+def test_otb_font(assert_pixels):
+    assert_pixels('''
+        ____________________
+        __RR______RR________
+        __RR__RR__RR________
+        __RR__RR__RR________
+        ____________________
+        ____________________
+    ''', '''
+      <style>
+        @page {
+          size: 20px 6px;
+          margin: 1px;
+        }
+        @font-face {
+          src: url(weasyprint.otb);
+          font-family: weasyprint-otb;
+        }
+        body {
+          color: red;
+          font-family: weasyprint-otb;
+          font-size: 4px;
+          line-height: 1;
+        }
+      </style>
+      AaA''')
