@@ -12,7 +12,6 @@ def test_inline_footnote():
             @font-face {src: url(weasyprint.otf); font-family: weasyprint}
             @page {
                 size: 9px 7px;
-                background: white;
             }
             div {
                 font-family: weasyprint;
@@ -46,7 +45,6 @@ def test_block_footnote():
          @font-face {src: url(weasyprint.otf); font-family: weasyprint}
          @page {
              size: 9px 7px;
-             background: white;
          }
          div {
              font-family: weasyprint;
@@ -79,7 +77,6 @@ def test_long_footnote():
             @font-face {src: url(weasyprint.otf); font-family: weasyprint}
             @page {
                 size: 9px 7px;
-                background: white;
             }
             div {
                 font-family: weasyprint;
@@ -123,7 +120,6 @@ def test_after_marker_footnote():
             @font-face {src: url(weasyprint.otf); font-family: weasyprint}
             @page {
                 size: 9px 7px;
-                background: white;
             }
             div {
                 font-family: weasyprint;
@@ -150,7 +146,6 @@ def test_several_footnote():
             @font-face {src: url(weasyprint.otf); font-family: weasyprint}
             @page {
                 size: 9px 7px;
-                background: white;
             }
             div {
                 font-family: weasyprint;
@@ -196,7 +191,6 @@ def test_reported_footnote_1():
             @font-face {src: url(weasyprint.otf); font-family: weasyprint}
             @page {
                 size: 9px 7px;
-                background: white;
             }
             div {
                 font-family: weasyprint;
@@ -239,7 +233,6 @@ def test_reported_footnote_2():
             @font-face {src: url(weasyprint.otf); font-family: weasyprint}
             @page {
                 size: 9px 7px;
-                background: white;
             }
             div {
                 font-family: weasyprint;
@@ -284,7 +277,6 @@ def test_reported_footnote_3():
             @font-face {src: url(weasyprint.otf); font-family: weasyprint}
             @page {
                 size: 9px 10px;
-                background: white;
             }
             div {
                 font-family: weasyprint;
@@ -351,6 +343,33 @@ def test_reported_sequential_footnote():
     assert sorted(positions) == positions
 
 
+@assert_no_logs
+def test_reported_sequential_footnote_second_line():
+    pages = render_pages('''
+        <style>
+            @font-face {src: url(weasyprint.otf); font-family: weasyprint}
+            @page {
+                size: 9px 7px;
+            }
+            div {
+                font-family: weasyprint;
+                font-size: 2px;
+                line-height: 1;
+            }
+            span {
+                float: footnote;
+            }
+        </style>
+        <div>
+            aaa a<span>b</span><span>c</span><span>d</span><span>e</span>
+        </div>''')
+
+    positions = [
+        tree_position(pages, lambda box: getattr(box, 'text', None) == letter)
+        for letter in 'abc']
+    assert sorted(positions) == positions
+
+
 @assert_no_logs
 @pytest.mark.parametrize('css, tail', (
     ('p { break-inside: avoid }', '<br>e<br>f'),
@@ -364,7 +383,6 @@ def test_footnote_area_after_call(css, tail):
             @font-face {src: url(weasyprint.otf); font-family: weasyprint}
             @page {
                 size: 9px 10px;
-                background: white;
                 margin: 0;
             }
             body {
@@ -397,7 +415,6 @@ def test_footnote_display_inline():
             @font-face {src: url(weasyprint.otf); font-family: weasyprint}
             @page {
                 size: 9px 50px;
-                background: white;
             }
             div {
                 font-family: weasyprint;
@@ -436,7 +453,6 @@ def test_footnote_longer_than_space_left():
             @font-face {src: url(weasyprint.otf); font-family: weasyprint}
             @page {
                 size: 9px 7px;
-                background: white;
             }
             div {
                 font-family: weasyprint;
@@ -477,7 +493,6 @@ def test_footnote_longer_than_page():
             @font-face {src: url(weasyprint.otf); font-family: weasyprint}
             @page {
                 size: 9px 7px;
-                background: white;
             }
             div {
                 font-family: weasyprint;
@@ -518,7 +533,6 @@ def test_footnote_policy_line():
             @font-face {src: url(weasyprint.otf); font-family: weasyprint}
             @page {
                 size: 9px 9px;
-                background: white;
             }
             div {
                 font-family: weasyprint;
@@ -561,7 +575,6 @@ def test_footnote_policy_block():
             @font-face {src: url(weasyprint.otf); font-family: weasyprint}
             @page {
                 size: 9px 9px;
-                background: white;
             }
             div {
                 font-family: weasyprint;
@@ -602,7 +615,6 @@ def test_footnote_repagination():
             @font-face {src: url(weasyprint.otf); font-family: weasyprint}
             @page {
                 size: 9px 7px;
-                background: white;
             }
             div {
                 font-family: weasyprint;
