@@ -539,6 +539,29 @@ def test_recto_verso_break(direction, page_break, pages_number):
     assert len(pages) == pages_number
 
 
+@assert_no_logs
+@pytest.mark.parametrize('direction, page_break, first_page', (
+    ('ltr', 'recto', 'right'),
+    ('ltr', 'verso', 'left'),
+    ('rtl', 'recto', 'left'),
+    ('rtl', 'verso', 'right'),
+    ('ltr', 'right', 'right'),
+    ('ltr', 'left', 'left'),
+    ('rtl', 'right', 'right'),
+    ('rtl', 'left', 'left'),
+))
+def test_recto_verso_break_root(direction, page_break, first_page):
+    page, = render_pages('''
+      <style>
+        @page:left { size: 4px /* len('left') */ }
+        @page:right { size: 5px /* len('right') */ }
+        html { direction: %s; break-before: %s }
+      </style>
+      abc
+    ''' % (direction, page_break))
+    assert page.width == len(first_page)
+
+
 @assert_no_logs
 def test_page_names_1():
     pages = render_pages('''
@@ -1237,6 +1260,47 @@ def test_margin_boxes_vertical_align():
 
 @assert_no_logs
 def test_margin_boxes_element():
+    pages = render_pages('''
+      <style>
+        @page {
+          counter-increment: count;
+          counter-reset: page pages;
+          margin: 50px;
+          size: 200px;
+          @bottom-center {
+            content: counter(page) ' of ' counter(pages)
+                     ' (' counter(count) ')';
+          }
+        }
+        h1 {
+          height: 40px;
+        }
+      </style>
+      <h1>test1</h1>
+      <h1>test2</h1>
+      <h1>test3</h1>
+      <h1>test4</h1>
+      <h1>test5</h1>
+      <h1>test6</h1>
+    ''')
+    footer1_text = ''.join(
+        getattr(node, 'text', '')
+        for node in pages[0].children[1].descendants())
+    assert footer1_text == '0 of 3 (1)'
+
+    footer2_text = ''.join(
+        getattr(node, 'text', '')
+        for node in pages[1].children[1].descendants())
+    assert footer2_text == '0 of 3 (2)'
+
+    footer3_text = ''.join(
+        getattr(node, 'text', '')
+        for node in pages[2].children[1].descendants())
+    assert footer3_text == '0 of 3 (3)'
+
+
+@assert_no_logs
+def test_margin_boxes_running_element():
     pages = render_pages('''
       <style>
         footer {
@@ -1249,6 +1313,9 @@ def test_margin_boxes_element():
             content: element(footer);
           }
         }
+        body {
+          font-size: 1px
+        }
         h1 {
           height: 40px;
         }
