@@ -67,7 +67,7 @@ def test_font_face_3():
 
 @assert_no_logs
 def test_font_face_4():
-    # See bug #487
+    # Test regression: https://github.com/Kozea/WeasyPrint/issues/487
     stylesheet = tinycss2.parse_stylesheet(
         '@font-face {'
         '  font-family: Gentium Hard;'
@@ -82,6 +82,27 @@ def test_font_face_4():
     assert src == ('src', (('local', 'Gentium Hard'),))
 
 
+@assert_no_logs
+def test_font_face_5():
+    # Test regression: https://github.com/Kozea/WeasyPrint/issues/1653
+    stylesheet = tinycss2.parse_stylesheet(
+        '@font-face {'
+        '  font-family: Gentium Hard;'
+        '  src: local(Gentium Hard);'
+        '  src: local(Gentium Soft),'
+        '}')
+    at_rule, = stylesheet
+    assert at_rule.at_keyword == 'font-face'
+    with capture_logs() as logs:
+        font_family, src = list(preprocess_descriptors(
+            'font-face', 'http://weasyprint.org/foo/',
+            tinycss2.parse_declaration_list(at_rule.content)))
+    assert font_family == ('font_family', 'Gentium Hard')
+    assert src == ('src', (('local', 'Gentium Hard'),))
+    assert len(logs) == 1
+    assert 'invalid value' in logs[0]
+
+
 def test_font_face_bad_1():
     stylesheet = tinycss2.parse_stylesheet(
         '@font-face {'
@@ -112,11 +133,9 @@ def test_font_face_bad_1():
 def test_font_face_bad_2():
     stylesheet = tinycss2.parse_stylesheet('@font-face{}')
     with capture_logs() as logs:
-        descriptors = []
         preprocess_stylesheet(
             'print', 'http://wp.org/foo/', stylesheet, None, None, None,
-            descriptors, None, None)
-        assert not descriptors
+            None, None)
     assert logs == [
         "WARNING: Missing src descriptor in '@font-face' rule at 1:1"]
 
@@ -124,11 +143,9 @@ def test_font_face_bad_2():
 def test_font_face_bad_3():
     stylesheet = tinycss2.parse_stylesheet('@font-face{src: url(test.woff)}')
     with capture_logs() as logs:
-        descriptors = []
         preprocess_stylesheet(
             'print', 'http://wp.org/foo/', stylesheet, None, None, None,
-            descriptors, None, None)
-        assert not descriptors
+            None, None)
     assert logs == [
         "WARNING: Missing font-family descriptor in '@font-face' rule at 1:1"]
 
@@ -136,11 +153,9 @@ def test_font_face_bad_3():
 def test_font_face_bad_4():
     stylesheet = tinycss2.parse_stylesheet('@font-face{font-family: test}')
     with capture_logs() as logs:
-        descriptors = []
         preprocess_stylesheet(
             'print', 'http://wp.org/foo/', stylesheet, None, None, None,
-            descriptors, None, None)
-        assert not descriptors
+            None, None)
     assert logs == [
         "WARNING: Missing src descriptor in '@font-face' rule at 1:1"]
 
@@ -149,11 +164,9 @@ def test_font_face_bad_5():
     stylesheet = tinycss2.parse_stylesheet(
         '@font-face { font-family: test; src: wrong }')
     with capture_logs() as logs:
-        descriptors = []
         preprocess_stylesheet(
             'print', 'http://wp.org/foo/', stylesheet, None, None, None,
-            descriptors, None, None)
-        assert not descriptors
+            None, None)
     assert logs == [
         'WARNING: Ignored `src: wrong ` at 1:33, invalid value.',
         "WARNING: Missing src descriptor in '@font-face' rule at 1:1"]
@@ -163,11 +176,9 @@ def test_font_face_bad_6():
     stylesheet = tinycss2.parse_stylesheet(
         '@font-face { font-family: good, bad; src: url(test.woff) }')
     with capture_logs() as logs:
-        descriptors = []
         preprocess_stylesheet(
             'print', 'http://wp.org/foo/', stylesheet, None, None, None,
-            descriptors, None, None)
-        assert not descriptors
+            None, None)
     assert logs == [
         'WARNING: Ignored `font-family: good, bad` at 1:14, invalid value.',
         "WARNING: Missing font-family descriptor in '@font-face' rule at 1:1"]
@@ -177,11 +188,9 @@ def test_font_face_bad_7():
     stylesheet = tinycss2.parse_stylesheet(
         '@font-face { font-family: good, bad; src: really bad }')
     with capture_logs() as logs:
-        descriptors = []
         preprocess_stylesheet(
             'print', 'http://wp.org/foo/', stylesheet, None, None, None,
-            descriptors, None, None)
-        assert not descriptors
+            None, None)
     assert logs == [
         'WARNING: Ignored `font-family: good, bad` at 1:14, invalid value.',
         'WARNING: Ignored `src: really bad ` at 1:38, invalid value.',
@@ -197,9 +206,7 @@ def test_font_face_bad_7():
 def test_counter_style_invalid(rule):
     stylesheet = tinycss2.parse_stylesheet(rule)
     with capture_logs() as logs:
-        descriptors = []
         preprocess_stylesheet(
             'print', 'http://wp.org/foo/', stylesheet, None, None, None,
-            descriptors, None, {})
-        assert not descriptors
+            None, {})
     assert len(logs) >= 1
